# User guides

``` {toctree}
:maxdepth: 1
:hidden:

../colabs/essential_commands
../exploring_model_metadata
../variant_scoring
../visualization_library_basics
```

<!-- mdformat off(Turn off mdformat to retain grid card syntax.) -->

::::{grid} 1 1 2 3
:gutter: 2

:::{grid-item-card} Essential commands
:link: ../colabs/essential_commands
:link-type: doc

Essential commands for navigating AlphaGenome.
:::

:::{grid-item-card} Model output metadata
:link: ../exploring_model_metadata
:link-type: doc

A summary of model outputs and associated metadata.
:::

:::{grid-item-card} Variant scoring
:link: ../variant_scoring
:link-type: doc

Overview of how variant scores are calculated.
:::

:::{grid-item-card} Visualization basics
:link: ../visualization_library_basics
:link-type: doc

Guide to visualization tools.
:::

<!-- mdformat on -->
